@@ -22,7 +22,7 @@ namespace Model
   class UpdateStreamModeRequest : public KinesisRequest
   {
   public:
-    AWS_KINESIS_API UpdateStreamModeRequest();
+    AWS_KINESIS_API UpdateStreamModeRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -44,14 +44,12 @@ namespace Model
      * <p> Specifies the ARN of the data stream whose capacity mode you want to update.
      * </p>
      */
-    inline const Aws::String& GetStreamARN() const{ return m_streamARN; }
+    inline const Aws::String& GetStreamARN() const { return m_streamARN; }
     inline bool StreamARNHasBeenSet() const { return m_streamARNHasBeenSet; }
-    inline void SetStreamARN(const Aws::String& value) { m_streamARNHasBeenSet = true; m_streamARN = value; }
-    inline void SetStreamARN(Aws::String&& value) { m_streamARNHasBeenSet = true; m_streamARN = std::move(value); }
-    inline void SetStreamARN(const char* value) { m_streamARNHasBeenSet = true; m_streamARN.assign(value); }
-    inline UpdateStreamModeRequest& WithStreamARN(const Aws::String& value) { SetStreamARN(value); return *this;}
-    inline UpdateStreamModeRequest& WithStreamARN(Aws::String&& value) { SetStreamARN(std::move(value)); return *this;}
-    inline UpdateStreamModeRequest& WithStreamARN(const char* value) { SetStreamARN(value); return *this;}
+    template<typename StreamARNT = Aws::String>
+    void SetStreamARN(StreamARNT&& value) { m_streamARNHasBeenSet = true; m_streamARN = std::forward<StreamARNT>(value); }
+    template<typename StreamARNT = Aws::String>
+    UpdateStreamModeRequest& WithStreamARN(StreamARNT&& value) { SetStreamARN(std::forward<StreamARNT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -60,12 +58,12 @@ namespace Model
      * Currently, in Kinesis Data Streams, you can choose between an <b>on-demand</b>
      * capacity mode and a <b>provisioned</b> capacity mode for your data streams. </p>
      */
-    inline const StreamModeDetails& GetStreamModeDetails() const{ return m_streamModeDetails; }
+    inline const StreamModeDetails& GetStreamModeDetails() const { return m_streamModeDetails; }
     inline bool StreamModeDetailsHasBeenSet() const { return m_streamModeDetailsHasBeenSet; }
-    inline void SetStreamModeDetails(const StreamModeDetails& value) { m_streamModeDetailsHasBeenSet = true; m_streamModeDetails = value; }
-    inline void SetStreamModeDetails(StreamModeDetails&& value) { m_streamModeDetailsHasBeenSet = true; m_streamModeDetails = std::move(value); }
-    inline UpdateStreamModeRequest& WithStreamModeDetails(const StreamModeDetails& value) { SetStreamModeDetails(value); return *this;}
-    inline UpdateStreamModeRequest& WithStreamModeDetails(StreamModeDetails&& value) { SetStreamModeDetails(std::move(value)); return *this;}
+    template<typename StreamModeDetailsT = StreamModeDetails>
+    void SetStreamModeDetails(StreamModeDetailsT&& value) { m_streamModeDetailsHasBeenSet = true; m_streamModeDetails = std::forward<StreamModeDetailsT>(value); }
+    template<typename StreamModeDetailsT = StreamModeDetails>
+    UpdateStreamModeRequest& WithStreamModeDetails(StreamModeDetailsT&& value) { SetStreamModeDetails(std::forward<StreamModeDetailsT>(value)); return *this;}
     ///@}
   private:
 
